# Francy Jupyter Lab Extension

This is part of the Francy project, please check documentation [here](https://github.com/gap-packages/francy).

A JupyterLab extension for rendering mime 'application/vnd.francy+json'.

## Install

```bash
jupyter labextension install jupyter-francy
```

Note: 
Make sure [JupyterKenel](https://github.com/gap-packages/JupyterKernel) is installed on Jupyter.
Make sure [Francy GAP](/) is installed on GAP.

# License

[MIT](LICENSE) License
